<?php
/**
 * Add Emails Page
 *
 * Copyright 2004 (c) Tim Perdue - GForge LLC
 * Copyright 2010 (c) Franck Villaume - Capgemini
 * http://fusionforge.org
 *
 * This file is part of FusionForge. FusionForge is free software;
 * you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the Licence, or (at your option)
 * any later version.
 *
 * FusionForge is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with FusionForge; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

/* Add emails to a mailing list */

require_once('../../../env.inc.php');
require_once $gfcommon.'include/pre.php';
require_once $gfcommon.'preplugins.php';
require_once $gfcommon.'include/utils.php';
require_once '../mailman_utils.php';

$request =& HTTPRequest::instance();
$group_id = $request->get('group_id');
$group_list_id = $request->get('group_list_id');

session_require_perm ('project_admin', $group_id) ;

$group = group_get_object($group_id);
if (!$group || !is_object($group)) {
    exit_no_group();
} elseif ($group->isError()) {
	exit_error($group->getErrorMessage(),'admin');
}

$ml = new MailmanList($group_id,$group_list_id);

if(!$ml || !is_object($ml)) {
	$error_msg = _('Error getting the list');
	session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
} elseif($ml->isError()) {
	$error_msg = $ml->getErrorMessage();
	session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
} else {	
	$listname = $ml->getName();
}

$list_emails = getStringFromRequest('list_emails');
if (!$list_emails) {
	$list_emails = array();
} else {
	$list_emails = explode(',',$list_emails);
}

$newEmail = getStringFromRequest('newemail');
if ($newEmail) {
	if (!validate_email($newEmail)) {
		$error_msg = _('Invalid email address.');
		session_redirect('/plugins/mailman/admin/addemails.php?group_id='.$group_id.'&group_list_id='.$group_list_id.'&list_emails='.implode(',',$list_emails).'&error_msg='.urlencode($error_msg));	
	} else {
		$list_emails[] = $newEmail;
	}
}
$list_emails = array_unique($list_emails);

$deleted_email = getStringFromRequest('deleted_email');

if ($deleted_email) {
	$key = array_search($deleted_email,$list_emails);
	if ($key !== false) {
		unset($list_emails[$key]);
	}
}

if (getStringFromRequest('finished')) {
	if (count($list_emails) == 0) {
	    $warning_msg = _('No member added');
		session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&warning_msg='.urlencode($warning_msg));		
	}
	foreach ($list_emails as $email) {
		$member = $ml->_mailingDAO->SearchUserByEmail($email,$listname);
		$arr_member = $member->getRow();
		if (strCmp($arr_member['name'],'') != 0) {
			$error_msg = $email.' '._('already member');
			session_redirect('/plugins/mailman/admin/addemails.php?group_id='.$group_id.'&group_list_id='.$group_list_id.'&list_emails='.implode(',',$list_emails).'&error_msg='.urlencode($error_msg));
		}
	}
	foreach ($list_emails as $email) {
		$name = _('Not a member of the forge');
		if (!$ml->_mailingDAO->newSubscriber($email,$name,'',$listname,'N')) {
			$error_msg = _('Error On Update:'. ' ' . $email);
			session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&error_msg='.urlencode($error_msg));
		}
	}
    $feedback = _('Members added successfully');
	session_redirect('/plugins/mailman/admin/index.php?group_id='.$group_id.'&feedback='.urlencode($feedback));	
}


mailman_header(array('title' => _('Add emails to the List').' '.$listname,
				'help'=>'CommunicationServices.html#MailingLists',
				'admin'=>1));

echo '<table><tr></tr><tr><td valign="top" width="25%">';

echo $HTML->boxTop(_('Emails'));
if (sizeof($list_emails)) {
	echo '<table>';
	$i = 1;
	foreach ($list_emails as $email){
		echo '<form action="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&group_list_id='.$group_list_id.'" method="post">
		<input type="hidden" name="list_emails" value="'. implode(',',$list_emails) .'" />';
		echo '<tr '.$HTML->boxGetAltRowStyle($i).'">';
		echo '<td>'.$email.'</td>';
		echo '<input type="hidden" name="deleted_email" value="'. $email .'"/>';
		echo '<td><input type="submit" value="'. _('Remove') .'" /></td></tr>';
		echo '</form>';
		$i++;
	}
	echo '</table>';
} else {
	echo '<p class="warning">'._('No emails').'</p>';
}
echo $HTML->boxBottom();
echo '</td><td valign="top" width="5%"></td><td valign="top" width="25%">';
echo $HTML->boxTop(_('Add a new email'));
echo '<form action="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&group_list_id='.$group_list_id.'" method="post">
<input type="hidden" name="list_emails" value="'. implode(',',$list_emails) .'" />';
echo '<table><tr>';
echo '<td>';
echo '<label>'._('Email').'</label></td><td><input name="newemail" type="text" size="30" /></td>';
echo '</tr><tr>';
echo '</tr><tr>';
echo '<td>';
echo '<input type="submit" value="'. _('Add') .'" />';
echo '</td>';
echo '</tr></table>';
echo '</form>';
echo $HTML->boxBottom();
echo '</td></tr></table>';

echo '<form action="'.getStringFromServer('PHP_SELF').'?group_id='.$group_id.'&group_list_id='.$group_list_id.'" method="post">
<input type="hidden" name="list_emails" value="'. implode(',',$list_emails) .'" />';
echo '<input type="submit" name="finished" value="'._('Finish').'" />';
echo '</form>';

mail_footer(array());

?>